RadiusNeighborsClassifier — hubness 0.21a1 documentation

# RadiusNeighborsClassifier

class `hubness.neighbors.` `RadiusNeighborsClassifier`(radius=1.0, weights='uniform', algorithm: str = 'auto', algorithm_params: dict = None, hubness: str = None, hubness_params: dict = None, leaf_size=30, p=2, metric='minkowski', outlier_label=None, metric_params=None, n_jobs=None, **kwargs)

  Bases: `hubness.neighbors.base.NeighborsBase`, `hubness.neighbors.base.RadiusNeighborsMixin`, `sklearn.neighbors.base.SupervisedIntegerMixin`, `sklearn.base.ClassifierMixin`

  Classifier implementing a vote among neighbors within a given radius Read more in the User Guide.

  Parameters

    - radius (float, optional (default = 1.0)) – Range of parameter space to use by default for `radius_neighbors()` queries.

    - weights (str or callable) –

      weight function used in prediction. Possible values: - ‘uniform’ : uniform weights. All points in each neighborhood

      > are weighted equally.

      - ’distance’ : weight points by the inverse of their distance. in this case, closer neighbors of a query point will have a greater influence than neighbors which are further away.

      - [callable] : a user-defined function which accepts an array of distances, and returns an array of the same shape containing the weights.

      Uniform weights are used by default.

    - algorithm ({'auto', 'ball_tree', 'kd_tree', 'brute'}, optional) –

      Algorithm used to compute the nearest neighbors: - ‘ball_tree’ will use `BallTree` - ‘kd_tree’ will use `KDTree` - ‘brute’ will use a brute-force search. - ‘auto’ will attempt to decide the most appropriate algorithm

      > based on the values passed to `fit()` method.

      Note: fitting on sparse input will override the setting of this parameter, using brute force.

    - leaf_size (int, optional (default = 30)) – Leaf size passed to BallTree or KDTree. This can affect the speed of the construction and query, as well as the memory required to store the tree. The optimal value depends on the nature of the problem.

    - p (integer, optional (default = 2)) – Power parameter for the Minkowski metric. When p = 1, this is equivalent to using manhattan_distance (l1), and euclidean_distance (l2) for p = 2. For arbitrary p, minkowski_distance (l_p) is used.

    - metric (string or callable, default 'minkowski') – the distance metric to use for the tree. The default metric is minkowski, and with p=2 is equivalent to the standard Euclidean metric. See the documentation of the DistanceMetric class for a list of available metrics.

    - outlier_label (int, optional (default = None)) – Label, which is given for outlier samples (samples with no neighbors on given radius). If set to None, ValueError is raised, when outlier is detected.

    - metric_params (dict, optional (default = None)) – Additional keyword arguments for the metric function.

    - n_jobs (int or None, optional (default=None)) – The number of parallel jobs to run for neighbors search. `None` means 1 unless in a `joblib.parallel_backend` context. `-1` means using all processors. See Glossary for more details.

  Examples

      >>> X = [[0], [1], [2], [3]]
      >>> y = [0, 0, 1, 1]
      >>> from hubness.neighbors import RadiusNeighborsClassifier
      >>> neigh = RadiusNeighborsClassifier(radius=1.0)
      >>> neigh.fit(X, y) # doctest: +ELLIPSIS
      RadiusNeighborsClassifier(...)
      >>> print(neigh.predict([[1.5]]))
      [0]

  See also

  `KNeighborsClassifier`, `RadiusNeighborsRegressor`, `KNeighborsRegressor`, `NearestNeighbors`

  Notes

  See Nearest Neighbors in the online documentation for a discussion of the choice of `algorithm` and `leaf_size`. https://en.wikipedia.org/wiki/K-nearest_neighbor_algorithm

  Methods Summary

  `predict`(X) | Predict the class labels for the provided data :param X: Test samples.

  Methods Documentation

  `predict`(X)

    Predict the class labels for the provided data :param X: Test samples. :type X: array-like, shape (n_query, n_features), or (n_query, n_indexed) if metric == ‘precomputed’

    Returns

      y – Class labels for each data sample.

    Return type

      array of shape [n_samples] or [n_samples, n_outputs]